# encoding: utf-8
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.

module Azure::Appconfiguration::Mgmt::V2020_06_01
  #
  # PrivateEndpointConnections
  #
  class PrivateEndpointConnections
    include MsRestAzure

    #
    # Creates and initializes a new instance of the PrivateEndpointConnections class.
    # @param client service class for accessing basic functionality.
    #
    def initialize(client)
      @client = client
    end

    # @return [AppConfigurationManagementClient] reference to the AppConfigurationManagementClient
    attr_reader :client

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [Array<PrivateEndpointConnection>] operation results.
    #
    def list_by_configuration_store(resource_group_name, config_store_name, custom_headers:nil)
      first_page = list_by_configuration_store_as_lazy(resource_group_name, config_store_name, custom_headers:custom_headers)
      first_page.get_all_items
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def list_by_configuration_store_with_http_info(resource_group_name, config_store_name, custom_headers:nil)
      list_by_configuration_store_async(resource_group_name, config_store_name, custom_headers:custom_headers).value!
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def list_by_configuration_store_async(resource_group_name, config_store_name, custom_headers:nil)
      fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
      fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
      fail ArgumentError, 'config_store_name is nil' if config_store_name.nil?
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MaxLength': '50'" if !config_store_name.nil? && config_store_name.length > 50
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MinLength': '5'" if !config_store_name.nil? && config_store_name.length < 5
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'Pattern': '^[a-zA-Z0-9_-]*$'" if !config_store_name.nil? && config_store_name.match(Regexp.new('^^[a-zA-Z0-9_-]*$$')).nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/privateEndpointConnections'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'configStoreName' => config_store_name},
          query_params: {'api-version' => @client.api_version},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:get, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnectionListResult.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

    #
    # Gets the specified private endpoint connection associated with the
    # configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [PrivateEndpointConnection] operation results.
    #
    def get(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      response = get_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # Gets the specified private endpoint connection associated with the
    # configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def get_with_http_info(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      get_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers).value!
    end

    #
    # Gets the specified private endpoint connection associated with the
    # configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def get_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
      fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
      fail ArgumentError, 'config_store_name is nil' if config_store_name.nil?
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MaxLength': '50'" if !config_store_name.nil? && config_store_name.length > 50
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MinLength': '5'" if !config_store_name.nil? && config_store_name.length < 5
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'Pattern': '^[a-zA-Z0-9_-]*$'" if !config_store_name.nil? && config_store_name.match(Regexp.new('^^[a-zA-Z0-9_-]*$$')).nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
      fail ArgumentError, 'private_endpoint_connection_name is nil' if private_endpoint_connection_name.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/privateEndpointConnections/{privateEndpointConnectionName}'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'configStoreName' => config_store_name,'privateEndpointConnectionName' => private_endpoint_connection_name},
          query_params: {'api-version' => @client.api_version},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:get, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnection.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

    #
    # Update the state of the specified private endpoint connection associated with
    # the configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param private_endpoint_connection [PrivateEndpointConnection] The private
    # endpoint connection properties.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [PrivateEndpointConnection] operation results.
    #
    def create_or_update(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:nil)
      response = create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param private_endpoint_connection [PrivateEndpointConnection] The private
    # endpoint connection properties.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [Concurrent::Promise] promise which provides async access to http
    # response.
    #
    def create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:nil)
      # Send request
      promise = begin_create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:custom_headers)

      promise = promise.then do |response|
        # Defining deserialization method.
        deserialize_method = lambda do |parsed_response|
          result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnection.mapper()
          parsed_response = @client.deserialize(result_mapper, parsed_response)
        end

        # Waiting for response.
        @client.get_long_running_operation_result(response, deserialize_method)
      end

      promise
    end

    #
    # Deletes a private endpoint connection.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    def delete(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      response = delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers).value!
      nil
    end

    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [Concurrent::Promise] promise which provides async access to http
    # response.
    #
    def delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      # Send request
      promise = begin_delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers)

      promise = promise.then do |response|
        # Defining deserialization method.
        deserialize_method = lambda do |parsed_response|
        end

        # Waiting for response.
        @client.get_long_running_operation_result(response, deserialize_method)
      end

      promise
    end

    #
    # Update the state of the specified private endpoint connection associated with
    # the configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param private_endpoint_connection [PrivateEndpointConnection] The private
    # endpoint connection properties.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [PrivateEndpointConnection] operation results.
    #
    def begin_create_or_update(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:nil)
      response = begin_create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # Update the state of the specified private endpoint connection associated with
    # the configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param private_endpoint_connection [PrivateEndpointConnection] The private
    # endpoint connection properties.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def begin_create_or_update_with_http_info(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:nil)
      begin_create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:custom_headers).value!
    end

    #
    # Update the state of the specified private endpoint connection associated with
    # the configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param private_endpoint_connection [PrivateEndpointConnection] The private
    # endpoint connection properties.
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def begin_create_or_update_async(resource_group_name, config_store_name, private_endpoint_connection_name, private_endpoint_connection, custom_headers:nil)
      fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
      fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
      fail ArgumentError, 'config_store_name is nil' if config_store_name.nil?
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MaxLength': '50'" if !config_store_name.nil? && config_store_name.length > 50
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MinLength': '5'" if !config_store_name.nil? && config_store_name.length < 5
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'Pattern': '^[a-zA-Z0-9_-]*$'" if !config_store_name.nil? && config_store_name.match(Regexp.new('^^[a-zA-Z0-9_-]*$$')).nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
      fail ArgumentError, 'private_endpoint_connection_name is nil' if private_endpoint_connection_name.nil?
      fail ArgumentError, 'private_endpoint_connection is nil' if private_endpoint_connection.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

      # Serialize Request
      request_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnection.mapper()
      request_content = @client.serialize(request_mapper,  private_endpoint_connection)
      request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

      path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/privateEndpointConnections/{privateEndpointConnectionName}'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'configStoreName' => config_store_name,'privateEndpointConnectionName' => private_endpoint_connection_name},
          query_params: {'api-version' => @client.api_version},
          body: request_content,
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:put, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200 || status_code == 201
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnection.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end
        # Deserialize Response
        if status_code == 201
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnection.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

    #
    # Deletes a private endpoint connection.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    #
    def begin_delete(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      response = begin_delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers).value!
      nil
    end

    #
    # Deletes a private endpoint connection.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def begin_delete_with_http_info(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      begin_delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:custom_headers).value!
    end

    #
    # Deletes a private endpoint connection.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param private_endpoint_connection_name [String] Private endpoint connection
    # name
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def begin_delete_async(resource_group_name, config_store_name, private_endpoint_connection_name, custom_headers:nil)
      fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
      fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
      fail ArgumentError, 'config_store_name is nil' if config_store_name.nil?
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MaxLength': '50'" if !config_store_name.nil? && config_store_name.length > 50
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'MinLength': '5'" if !config_store_name.nil? && config_store_name.length < 5
      fail ArgumentError, "'config_store_name' should satisfy the constraint - 'Pattern': '^[a-zA-Z0-9_-]*$'" if !config_store_name.nil? && config_store_name.match(Regexp.new('^^[a-zA-Z0-9_-]*$$')).nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
      fail ArgumentError, 'private_endpoint_connection_name is nil' if private_endpoint_connection_name.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/privateEndpointConnections/{privateEndpointConnectionName}'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'configStoreName' => config_store_name,'privateEndpointConnectionName' => private_endpoint_connection_name},
          query_params: {'api-version' => @client.api_version},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:delete, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200 || status_code == 202 || status_code == 204
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?

        result
      end

      promise.execute
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param next_page_link [String] The NextLink from the previous successful call
    # to List operation.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [PrivateEndpointConnectionListResult] operation results.
    #
    def list_by_configuration_store_next(next_page_link, custom_headers:nil)
      response = list_by_configuration_store_next_async(next_page_link, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param next_page_link [String] The NextLink from the previous successful call
    # to List operation.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def list_by_configuration_store_next_with_http_info(next_page_link, custom_headers:nil)
      list_by_configuration_store_next_async(next_page_link, custom_headers:custom_headers).value!
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param next_page_link [String] The NextLink from the previous successful call
    # to List operation.
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def list_by_configuration_store_next_async(next_page_link, custom_headers:nil)
      fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = '{nextLink}'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          skip_encoding_path_params: {'nextLink' => next_page_link},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:get, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Appconfiguration::Mgmt::V2020_06_01::Models::PrivateEndpointConnectionListResult.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

    #
    # Lists all private endpoint connections for a configuration store.
    #
    # @param resource_group_name [String] The name of the resource group to which
    # the container registry belongs.
    # @param config_store_name [String] The name of the configuration store.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [PrivateEndpointConnectionListResult] which provide lazy access to
    # pages of the response.
    #
    def list_by_configuration_store_as_lazy(resource_group_name, config_store_name, custom_headers:nil)
      response = list_by_configuration_store_async(resource_group_name, config_store_name, custom_headers:custom_headers).value!
      unless response.nil?
        page = response.body
        page.next_method = Proc.new do |next_page_link|
          list_by_configuration_store_next_async(next_page_link, custom_headers:custom_headers)
        end
        page
      end
    end

  end
end
